summaryrefslogtreecommitdiffstats
path: root/cpukit/score/src/threadclose.c
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-05-16 21:51:40 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-05-16 21:51:40 +0000
commitd9aca5f5376cea0053c5c099111c8adc8191974e (patch)
tree8dbb8e437a8b32f4eed503e41f7b581bba17a2c8 /cpukit/score/src/threadclose.c
parent2008-05-16 Joel Sherrill <joel.sherrill@OARcorp.com> (diff)
downloadrtems-d9aca5f5376cea0053c5c099111c8adc8191974e.tar.bz2
2008-05-16 Till Straumann <strauman@slac.stanford.edu>
* score/src/threadchangepriority.c: Just in case the transient state was set when we entered, ensure that it is still set when we exit. * score/src/threadclose.c: When a thread is being deleted, it should go into the dormant state -- not the transient state.
Diffstat (limited to 'cpukit/score/src/threadclose.c')
-rw-r--r--cpukit/score/src/threadclose.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/cpukit/score/src/threadclose.c b/cpukit/score/src/threadclose.c
index f8231a1192..a29aebdca7 100644
--- a/cpukit/score/src/threadclose.c
+++ b/cpukit/score/src/threadclose.c
@@ -66,10 +66,10 @@ void _Thread_Close(
_Objects_Close( information, &the_thread->Object );
/*
* By setting the transient state, the thread will not be considered
* for scheduling when we remove any blocking states.
*/
- _Thread_Set_state( the_thread, STATES_TRANSIENT );
+ _Thread_Set_state( the_thread, STATES_DORMANT );
if ( !_Thread_queue_Extract_with_proxy( the_thread ) ) {
if ( _Watchdog_Is_active( &the_thread->Timer ) )
@@ -66,10 +66,10 @@ void _Thread_Close(
_Objects_Close( information, &the_thread->Object );
/*
- * By setting the transient state, the thread will not be considered
+ * By setting the dormant state, the thread will not be considered
* for scheduling when we remove any blocking states.
*/